@@ -83,11 +83,13 @@ class Entity(object):
 
 
 class Notification(object):
-    def __init__(self, id, label, type, details, driver=None):
+    def __init__(self, id, label, type, details,
+                 driver=None,  metadata=None):
         self.id = id
         self.label = label
         self.type = type
         self.details = details
+        self.metadata = metadata
         self.driver = driver
 
     def update(self, data):
@@ -106,12 +108,13 @@ class NotificationPlan(object):
     Represents a notification plan.
     """
     def __init__(self, id, label, driver, critical_state=None,
-                 warning_state=None, ok_state=None):
+                 warning_state=None, ok_state=None, metadata=None):
         self.id = id
         self.label = label
         self.critical_state = critical_state
         self.warning_state = warning_state
         self.ok_state = ok_state
+        self.metadata = metadata
         self.driver = driver
 
     def update(self, data):
@@ -164,7 +167,7 @@ class NotificationType(object):
 
 class Alarm(object):
     def __init__(self, id, check_id, criteria, driver, entity_id, label=None,
-                 notification_plan_id=None):
+                 notification_plan_id=None, confd_name=None, confd_hash=None, metadata=None):
         self.id = id
         self.check_id = check_id
         self.criteria = criteria
@@ -172,6 +175,9 @@ class Alarm(object):
         self.notification_plan_id = notification_plan_id
         self.label = label
         self.entity_id = entity_id
+        self.confd_name = confd_name
+        self.confd_hash = confd_hash
+        self.metadata = metadata
 
     def update(self, data):
         self.driver.update_alarm(alarm=self, data=data)
@@ -186,7 +192,7 @@ class Alarm(object):
 class Check(object):
     def __init__(self, id, label, timeout, period, monitoring_zones,
                  target_alias, target_resolver, type, details,
-                 entity_id, disabled, driver):
+                 entity_id, disabled, driver, confd_name=None, confd_hash=None, metadata=None):
         self.id = id
         self.label = label
         self.timeout = timeout
@@ -198,6 +204,9 @@ class Check(object):
         self.details = details
         self.entity_id = entity_id
         self.disabled = disabled
+        self.confd_name = confd_name
+        self.confd_hash = confd_hash
+        self.metadata = metadata
         self.driver = driver
 
     def update(self, data):
@@ -292,6 +301,57 @@ class AgentConnection(object):
             (self.id, self.agent_id, self.guid)).encode('utf-8')
 
 
+class Suppression(object):
+    def __init__(self, id, notification_plans, entities,
+                 checks, alarms, start_time, end_time, driver):
+        self.id = id
+        self.notification_plans = notification_plans
+        self.entities = entities
+        self.checks = checks
+        self.alarms = alarms
+        self.start_time = start_time
+        self.end_time = end_time
+        self.driver = driver
+
+    def update(self, data):
+        self.driver.update_suppression(notification=self, data=data)
+
+    def delete(self):
+        return self.driver.delete_suppression(self)
+
+    def __str__(self):
+        return self.__repr__()
+
+    def __repr__(self):
+        return ('<Suppression: id=%s, start_time=%s, end_time=%s>' %
+            (self.id, self.start_time, self.end_time)).encode('utf-8')
+
+
+class SuppressionLog(object):
+    def __init__(self, id, entity_id, alarm_id, check_id, notification_plan_id,
+            suppressions, state, timestamp, transaction_id, driver):
+        self.id = id
+        self.entity_id = entity_id
+        self.alarm_id = alarm_id
+        self.check_id = check_id
+        self.notification_plan_id = notification_plan_id
+        self.suppressions = suppressions
+        self.state = state
+        self.timestamp = timestamp
+        self.transaction_id = transaction_id
+        self.driver = driver
+
+
+    def __str__(self):
+        return self.__repr__()
+
+    def __repr__(self):
+        return ('<SuppressionLog: id=%s, entity=%s, alarm=%s, check=%s,'
+                'state=%s, timestamp=%s>' %
+            (self.id, self.entity_id, self.alarm_id, self.check_id,
+             self.state, self.timestamp)).encode('utf-8')
+
+
 class MonitoringDriver(object):
     """
     A base MonitoringDriver to derive from.
@@ -359,6 +419,14 @@ class MonitoringDriver(object):
         raise NotImplementedError(
             'list_notification_plans not implemented for this driver')
 
+    def list_suppressions(self):
+        raise NotImplementedError(
+            'list_suppressions not implemented for this driver')
+
+    def list_suppression_logs(self):
+        raise NotImplementedError(
+            'list_suppression_logs not implemented for this driver')
+
     def delete_entity(self, entity):
         raise NotImplementedError(
             'delete_entity not implemented for this driver')
@@ -379,6 +447,10 @@ class MonitoringDriver(object):
         raise NotImplementedError(
             'delete_notification_plan not implemented for this driver')
 
+    def delete_suppression(self, suppression):
+        raise NotImplementedError(
+            'delete_suppression not implemented for this driver')
+
     def create_check(self, **kwargs):
         raise NotImplementedError(
             'create_check not implemented for this driver')
@@ -399,6 +471,10 @@ class MonitoringDriver(object):
         raise NotImplementedError(
             'create_notification_plan not implemented for this driver')
 
+    def create_suppression(self, **kwargs):
+        raise NotImplementedError(
+            'create_suppression not implemented for this driver')
+
     def update_entity(self, entity, data):
         raise NotImplementedError(
             'update_entity not implemented for this driver')
@@ -418,3 +494,7 @@ class MonitoringDriver(object):
     def update_notification_plan(self, notification_plan, data):
         raise NotImplementedError(
             'update_notification_plan not implemented for this driver')
+
+    def update_suppression(self, suppression, data):
+        raise NotImplementedError(
+            'update_suppression not implemented for this driver')
